export declare namespace MatchersV3 {
    /**
     * Pact Matcher
     */
    interface Matcher {
        "pact:matcher:type": string;
        "pact:generator:type"?: string;
        value?: any;
    }
    /**
     * Value must match the given template
     * @param template Template to base the comparison on
     */
    function like(template: any): Matcher;
    /**
     * Array where each element must match the given template
     * @param template Template to base the comparison on
     */
    function eachLike(template: any): Matcher;
    /**
     * Like Matcher with a minimum number of required values
     */
    interface MinLikeMatcher extends Matcher {
        min: number;
    }
    /**
     * An array that has to have at least one element and each element must match the given template
     * @param template Template to base the comparison on
     * @param count Number of examples to generate, defaults to one
     */
    function atLeastOneLike(template: any, count?: number): MinLikeMatcher;
    /**
     * An array that has to have at least the required number of elements and each element must match the given template
     * @param template Template to base the comparison on
     * @param min Minimum number of elements required in the array
     * @param count Number of examples to generate, defaults to one
     */
    function atLeastLike(template: any, min: number, count?: number): MinLikeMatcher;
    /**
     * Like Matcher with a maximum number of required values
     */
    interface MaxLikeMatcher extends Matcher {
        max: number;
    }
    /**
     * An array that has to have at most the required number of elements and each element must match the given template
     * @param template Template to base the comparison on
     * @param max Maximum number of elements required in the array
     * @param count Number of examples to generate, defaults to one
     */
    function atMostLike(template: any, max: number, count?: number): MaxLikeMatcher;
    /**
     * An array whose size is constrained to the minimum and maximum number of elements and each element must match the given template
     * @param template Template to base the comparison on
     * @param min Minimum number of elements required in the array
     * @param max Maximum number of elements required in the array
     * @param count Number of examples to generate, defaults to one
     */
    function constrainedArrayLike(template: any, min: number, max: number, count?: number): MinLikeMatcher & MaxLikeMatcher;
    /**
     * Value must be a boolean
     * @param b Boolean example value
     */
    function boolean(b: boolean): Matcher;
    /**
     * Value must be an integer (must be a number and have no decimal places)
     * @param int Example value. If omitted a random value will be generated.
     */
    function integer(int?: number): Matcher;
    /**
     * Value must be a decimal number (must be a number and have decimal places)
     * @param num Example value. If omitted a random value will be generated.
     */
    function decimal(num?: number): Matcher;
    /**
     * Value must be a number
     * @param num Example value. If omitted a random integer value will be generated.
     */
    function number(num?: number): Matcher;
    /**
     * Value must be a string
     * @param str Example value
     */
    function string(str: string): Matcher;
    interface RegexMatcher extends Matcher {
        regex: string;
        example?: string;
    }
    /**
     * Value that must match the given regular expression
     * @param pattern Regular Expression to match
     * @param str Example value
     */
    function regex(pattern: string, str: string): RegexMatcher;
    /**
     * Value that must match the given regular expression
     * @param pattern Regular Expression to match
     * @param str Example value
     */
    function regex(pattern: RegExp, str: string): RegexMatcher;
    /**
     * Value that must be equal to the example. This is mainly used to reset the matching rules which cascade.
     * @param value Example value
     */
    function equal(value: any): Matcher;
    interface DateTimeMatcher extends Matcher {
        format: string;
    }
    /**
     * String value that must match the provided datetime format string.
     * @param format Datetime format string. See [Java SimpleDateFormat](https://docs.oracle.com/javase/8/docs/api/java/text/SimpleDateFormat.html)
     * @param example Example value to use. If omitted a value using the current system date and time will be generated.
     */
    function timestamp(format: string, example?: string): DateTimeMatcher;
    /**
     * String value that must match the provided datetime format string.
     * @param format Datetime format string. See [Java SimpleDateFormat](https://docs.oracle.com/javase/8/docs/api/java/text/SimpleDateFormat.html)
     * @param example Example value to use. If omitted a value using the current system date and time will be generated.
     */
    function datetime(format: string, example?: string): DateTimeMatcher;
    /**
     * String value that must match the provided time format string.
     * @param format Time format string. See [Java SimpleDateFormat](https://docs.oracle.com/javase/8/docs/api/java/text/SimpleDateFormat.html)
     * @param example Example value to use. If omitted a value using the current system time will be generated.
     */
    function time(format: string, example?: string): DateTimeMatcher;
    /**
     * String value that must match the provided date format string.
     * @param format Date format string. See [Java SimpleDateFormat](https://docs.oracle.com/javase/8/docs/api/java/text/SimpleDateFormat.html)
     * @param example Example value to use. If omitted a value using the current system date will be generated.
     */
    function date(format: any, example?: string): DateTimeMatcher;
    /**
     * Value that must include the example value as a substring.
     * @param value String value to include
     */
    function includes(value: string): Matcher;
    /**
     * Value that must be null. This will only match the JSON Null value. For other content types, it will
     * match if the attribute is missing.
     */
    function nullValue(): Matcher;
    /**
     * Matches a URL composed of a list of path fragments. The base URL from the mock server will be used.
     * @param pathFragments list of path fragments, can be regular expressions
     */
    function url(pathFragments: Array<string | RegexMatcher | RegExp>): RegexMatcher;
    /**
     * Matches a URL composed of a base path and a list of path fragments
     * @param basePath Base path of the URL. If null, will use the base URL from the mock server.
     * @param pathFragments list of path fragments, can be regular expressions
     */
    function url2(basePath: string | null, pathFragments: Array<string | RegexMatcher | RegExp>): RegexMatcher;
    interface ArrayContainsMatcher extends Matcher {
        variants: any[];
    }
    /**
     * Matches the items in an array against a number of variants. Matching is successful if each variant
     * occurs once in the array. Variants may be objects containing matching rules.
     */
    function arrayContaining(...variants: any[]): ArrayContainsMatcher;
    interface ProviderStateInjectedValue extends Matcher {
        expression: string;
    }
    /**
     * Marks a item as to be injected from the provider state
     * @param expression Expression to lookup in the provider state context
     * @param exampleValue Example value to use in the consumer test
     */
    function fromProviderState(expression: string, exampleValue: string): ProviderStateInjectedValue;
    /**
     * Match a universally unique identifier (UUID). Random values will be used for examples if no example is given.
     */
    function uuid(example?: string): RegexMatcher;
}
